@@ -108,7 +108,7 @@ class Action0Property(BaseAction0Property):
 # Summary: If 'string' or 'string_literal' is set, the value should be a
 # string or literal string, else the value is a number. 'unit_type' and
 # 'unit_conversion' are used to convert user-entered values to nfo values.
-# If some more arithmetic is needed to convert the entered value into an nfo
+# If some more arithmetic is needed to convert the entered value into a nfo
 # value, 'value_function' can be used. For even more complicated things,
 # 'custom_function' can be used to create a special mapping of the value to nfo
 # properties, else 'num' and 'size' are used to provide a 'normal' action0.
@@ -214,7 +214,7 @@ def two_byte_property(low_prop, high_prop, low_prop_info=None, high_prop_info=No
 def animation_info(value, loop_bit=8, max_frame=253):
     """
     Convert animation info array of two elements to an animation info property.
-    The first is 0/1, and defines whether or not the animation loops.
+    The first is 0/1, and defines whether the animation loops.
     The second is the number of frames, at most 253 frames.
 
     @param value: Array of animation info.
@@ -412,6 +412,16 @@ def refittable_cargo_classes(prop_or_num, prop_and_num, refit_mask_num):
     ]
 
 
+def single_or_list(prop_name, single_num, multiple_num, value):
+    if isinstance(value, ConstantNumeric):
+        return [Action0Property(single_num, value, 1)]
+    if isinstance(value, Array):
+        if len(value.values) == 1:
+            return [Action0Property(single_num, value.values[0].reduce_constant(), 1)]
+        return [VariableByteListProp(multiple_num, [[type.reduce_constant().value for type in value.values]])]
+    raise generic.ScriptError("'{}' must be a constant or an array of constants".format(prop_name))
+
+
 #
 # Feature 0x00 (Trains)
 #
@@ -419,7 +429,9 @@ def refittable_cargo_classes(prop_or_num, prop_and_num, refit_mask_num):
 # fmt: off
 properties[0x00] = {
     **general_veh_props,
-    "track_type":                     {"size": 1, "num": 0x05},
+    "track_type": {
+        "custom_function": lambda value: single_or_list("track_type", 0x05, 0x34, value)
+    },
     "ai_special_flag":                {"size": 1, "num": 0x08},
     "speed": {
         "size": 2,
@@ -428,12 +440,12 @@ properties[0x00] = {
         "unit_conversion": (5000, 1397),
         "adjust_value": lambda val, unit: ottd_display_speed(val, 1, 1, unit)
     },
-    # 09 doesn"t exist
+    # 09 doesn't exist
     "power":                          {"size": 2, "num": 0x0B, "unit_type": "power"},
-    # 0A doesn"t exist
+    # 0A doesn't exist
     "running_cost_factor":            {"size": 1, "num": 0x0D},
     "running_cost_base":              {"size": 4, "num": 0x0E},
-    # 0F -11 don"t exist
+    # 0F -11 don't exist
     "sprite_id":                      {"size": 1, "num": 0x12},
     "dual_headed":                    {"size": 1, "num": 0x13},
     "cargo_capacity":                 {"size": 1, "num": 0x14},
@@ -717,7 +729,7 @@ properties[0x03] = {
 
 def station_platforms_length(value):
     # Writing bitmask(2) to disable platform/length 3 is not very intuitive.
-    # Instead we expect the user will write bitmask(3) and we shift the result.
+    # Instead, we expect the user will write bitmask(3) and we shift the result.
     return nmlop.SHIFT_RIGHT(value, 1, value.pos).reduce()
 
 
@@ -818,6 +830,12 @@ def station_tile_flags(value):
     ]
 
 
+def station_tile_list(value, prop_num, description):
+    if not isinstance(value, Array) or len(value.values) % 2 != 0:
+        raise generic.ScriptError(f"{description} list must be an array of even length", value.pos)
+    return [VariableByteListProp(prop_num, [[x.reduce_constant().value for x in value.values]], True)]
+
+
 # fmt: off
 properties[0x04] = {
     "class":                 {"size": 4, "num": 0x08, "first": None, "string_literal": 4},
@@ -843,6 +861,8 @@ properties[0x04] = {
     "name":                  {"size": 2, "num": (256, -1, 0x1C), "string": (256, 0xC5, 0xDC), "required": True},
     "classname":             {"size": 2, "num": (256, -1, 0x1D), "string": (256, 0xC4, 0xDC)},
     "tile_flags":            {"custom_function": station_tile_flags},  # = prop 1E
+    "heights":               {"custom_function": lambda x: station_tile_list(x, 0x20, "Station height")},
+    "blocked_pillars":       {"custom_function": lambda x: station_tile_list(x, 0x21, "Station blocked pillar")},
 }
 # fmt: on
 
@@ -1566,7 +1586,7 @@ properties[0x10] = {
 properties[0x11] = {
     "substitute":         {"size": 1, "num": 0x08, "first": None},
     "override":           {"size": 1, "num": 0x09},
-    # 0A - 0D don"t exist (yet?)
+    # 0A - 0D don't exist (yet?)
     # 0E (callback flags) is not set by user
     "animation_info":     {"size": 2, "num": 0x0F, "value_function": animation_info},
     "animation_speed":    {"size": 1, "num": 0x10},
@@ -1656,5 +1676,7 @@ properties[0x14] = {
     "animation_triggers":        {"size": 2, "num": 0x10},
     # 11 (callback flags) is not set by user
     "general_flags":             {"size": 4, "num": 0x12},
+    "heights":                   {"custom_function": lambda x: station_tile_list(x, 0x13, "Station height")},
+    "blocked_pillars":           {"custom_function": lambda x: station_tile_list(x, 0x14, "Station blocked pillar")},
     "cost_multipliers":          {"custom_function": lambda x: byte_sequence_list(x, 0x15, "Cost multipliers", 2)},
 }
