@@ -212,6 +212,7 @@ varact2vars_aircraft = {
     'max_speed'           : {'var': 0x98, 'start': 0, 'size': 16, 'value_function': value_mul_div(0x3939, 0x1000)},
     'current_speed'       : {'var': 0xB4, 'start': 0, 'size': 16, 'value_function': value_mul_div(0x3939, 0x1000)},
     'current_max_speed'   : {'var': 0x4C, 'start': 0, 'size': 16, 'value_function': value_mul_div(0x3939, 0x1000)},
+    'flight_state'        : {'var': 0xE2, 'start': 0, 'size':  8},
     'vehicle_is_in_depot' : {'var': 0xE6, 'start': 0, 'size':  8, 'value_function': value_equals(0)},
 }
 
@@ -297,7 +298,7 @@ varact2vars60x_base_stations = {
 varact2vars_stations = {
     **varact2vars_base_stations,
     # Vars 40, 41, 46, 47, 49 are implemented as 60+x vars,
-    # except for the 'tile type' part which is always the same anyways
+    # except for the 'tile type' part which is always the same anyway
     'tile_type'                : {'var': 0x40, 'start': 24, 'size': 8},
     'terrain_type'             : {'var': 0x42, 'start':  0, 'size': 8},
     'track_type'               : {'var': 0x42, 'start':  8, 'size': 8},
@@ -697,6 +698,9 @@ varact2vars_railtype = {
     'level_crossing_status' : {'var': 0x42, 'start': 0, 'size':  8},
     'build_date'            : {'var': 0x43, 'start': 0, 'size': 32},
     'town_zone'             : {'var': 0x44, 'start': 0, 'size':  8},
+    'roadtype'              : {'var': 0x45, 'start': 0, 'size':  8},
+    'tramtype'              : {'var': 0x45, 'start': 8, 'size':  8},
+    'railtype'              : {'var': 0x45, 'start': 16, 'size': 8},
     'random_bits'           : {'var': 0x5F, 'start': 8, 'size':  2},
 }
 # Railtypes have no 60+x variables
@@ -738,6 +742,9 @@ varact2vars_roadtype = {
     'level_crossing_status' : {'var': 0x42, 'start': 0, 'size':  8},
     'build_date'            : {'var': 0x43, 'start': 0, 'size': 32},
     'town_zone'             : {'var': 0x44, 'start': 0, 'size':  8},
+    'roadtype'              : {'var': 0x45, 'start': 0, 'size':  8},
+    'tramtype'              : {'var': 0x45, 'start': 8, 'size':  8},
+    'railtype'              : {'var': 0x45, 'start': 16, 'size': 8},
     'random_bits'           : {'var': 0x5F, 'start': 8, 'size':  2},
 }
 # Roadtypes have no 60+x variables
@@ -752,6 +759,9 @@ varact2vars_tramtype = {
     'level_crossing_status' : {'var': 0x42, 'start': 0, 'size':  8},
     'build_date'            : {'var': 0x43, 'start': 0, 'size': 32},
     'town_zone'             : {'var': 0x44, 'start': 0, 'size':  8},
+    'roadtype'              : {'var': 0x45, 'start': 0, 'size':  8},
+    'tramtype'              : {'var': 0x45, 'start': 8, 'size':  8},
+    'railtype'              : {'var': 0x45, 'start': 16, 'size': 8},
     'random_bits'           : {'var': 0x5F, 'start': 8, 'size':  2},
 }
 # Tramtypes have no 60+x variables
@@ -892,11 +902,11 @@ varact2features = [
     VarAct2Feature(scope_industries, scope_towns),
     VarAct2Feature(scope_cargos, None),
     VarAct2Feature(scope_soundeffects, None),
-    VarAct2Feature(scope_airports, None),
+    VarAct2Feature(scope_airports, scope_towns),
     None,  # signals
     VarAct2Feature(scope_objects, scope_towns),
     VarAct2Feature(scope_railtypes, None),
-    VarAct2Feature(scope_airporttiles, None),
+    VarAct2Feature(scope_airporttiles, scope_airports),
     VarAct2Feature(scope_roadtypes, None),
     VarAct2Feature(scope_tramtypes, None),
     VarAct2Feature(scope_roadstops, scope_towns),
