@@ -79,11 +79,13 @@ action5_table = {
     "AQUEDUCTS": (0x12, 8, Action5BlockType.OFFSET),
     "AUTORAIL": (0x13, 55, Action5BlockType.OFFSET),
     "FLAGS": (0x14, 36, Action5BlockType.OFFSET),
-    "OTTD_GUI": (0x15, 191, Action5BlockType.OFFSET),
+    "OTTD_GUI": (0x15, 192, Action5BlockType.OFFSET),
     "AIRPORT_PREVIEW": (0x16, 9, Action5BlockType.OFFSET),
     "RAILTYPE_TUNNELS": (0x17, 16, Action5BlockType.OFFSET),
     "OTTD_RECOLOUR": (0x18, 1, Action5BlockType.OFFSET),
     "ROAD_WAYPOINTS": (0x19, 4, Action5BlockType.OFFSET),
+    "OVERLAY_ROCKS": (0x1A, 95, Action5BlockType.OFFSET),
+    "BRIDGE_DECKS": (0x1B, 24, Action5BlockType.OFFSET),
 }
 
 
