@@ -65,7 +65,7 @@ class AltSpritesBlock(base_statement.BaseStatement):
             self.bit_depth = global_constants.bit_depths[param_list[2].value]
         else:
             raise generic.ScriptError(
-                "value for alternative_sprites parameter 3 'bit depth' is not a valid bit depthl", param_list[2].pos
+                "value for alternative_sprites parameter 3 'bit depth' is not a valid bit depth", param_list[2].pos
             )
         if self.bit_depth == 32:
             global_constants.any_32bpp_sprites = global_constants.allow_32bpp
