@@ -37,7 +37,9 @@ class Boolean(Expression):
     def reduce(self, id_dicts=None, unknown_id_fatal=True):
         expr = self.expr.reduce(id_dicts)
         if expr.type() != Type.INTEGER:
-            raise generic.ScriptError("Only integers can be converted to a boolean value.", self.pos)
+            if expr.type() == Type.SPRITEGROUP_REF:
+                raise generic.ProcCallSyntaxError(expr.name, expr.pos)
+            raise generic.ScriptError("Only integers can be converted to a boolean value.", expr.pos)
         if expr.is_boolean():
             return expr
         return Boolean(expr)
