@@ -13,9 +13,13 @@ You should have received a copy of the GNU General Public License along
 with NML; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA."""
 
+from itertools import chain
+
 from nml import generic
 from nml.actions import action2
-from .base_expression import Type, Expression
+
+from .base_expression import Expression, Type
+
 
 class SpriteGroupRef(Expression):
     """
@@ -34,23 +38,24 @@ class SpriteGroupRef(Expression):
                     To be used for action2s that have no direct equivalent in the AST
     @type act2: L{Action2}
     """
-    def __init__(self, name, param_list, pos, act2 = None):
+
+    def __init__(self, name, param_list, pos, act2=None):
+        super().__init__(pos)
         self.name = name
         self.param_list = param_list
-        self.pos = pos
         self.act2 = act2
         self.is_procedure = False
 
     def debug_print(self, indentation):
-        generic.print_dbg(indentation, 'Reference to:', self.name)
+        generic.print_dbg(indentation, "Reference to:", self.name)
         if len(self.param_list) != 0:
-            generic.print_dbg(indentation, 'Parameters:')
+            generic.print_dbg(indentation, "Parameters:")
             for p in self.param_list:
                 p.debug_print(indentation + 2)
 
     def __str__(self):
         if self.param_list:
-            return '{}({})'.format(self.name, ', '.join(str(x) for x in self.param_list))
+            return "{}({})".format(self.name, ", ".join(str(x) for x in self.param_list))
         return str(self.name)
 
     def get_action2_id(self, feature):
@@ -63,8 +68,10 @@ class SpriteGroupRef(Expression):
         @return: The set ID
         @rtype: C{int}
         """
-        if self.act2 is not None: return self.act2.id
-        if self.name.value == 'CB_FAILED': return 0 # 0 serves as a failed CB result because it is never used
+        if self.act2 is not None:
+            return self.act2.id
+        if self.name.value == "CB_FAILED":
+            return 0  # 0 serves as a failed CB result because it is never used
         try:
             spritegroup = action2.resolve_spritegroup(self.name)
         except generic.ScriptError:
@@ -72,21 +79,37 @@ class SpriteGroupRef(Expression):
 
         return spritegroup.get_action2(feature).id
 
-    def reduce(self, id_dicts = [], unknown_id_fatal = True):
+    def reduce(self, id_dicts=None, unknown_id_fatal=True):
+        if self.name.value != "CB_FAILED" and not self.is_procedure:
+            spritegroup = action2.resolve_spritegroup(self.name)
+            if spritegroup.optimise():
+                return spritegroup.optimised
         return self
 
     def supported_by_action2(self, raise_error):
         return True
 
     def collect_references(self):
-        return [self]
+        return list(chain([self], *(p.collect_references() for p in self.param_list)))
+
+    def is_read_only(self):
+        if self.name.value != "CB_FAILED":
+            spritegroup = action2.resolve_spritegroup(self.name)
+            return spritegroup.is_read_only()
+        return True
 
     def type(self):
-        if self.is_procedure: return Type.INTEGER
+        if self.is_procedure:
+            return Type.INTEGER
         return Type.SPRITEGROUP_REF
 
     def __eq__(self, other):
-        return other is not None and isinstance(other, SpriteGroupRef) and other.name == self.name and other.param_list == self.param_list
+        return (
+            other is not None
+            and isinstance(other, SpriteGroupRef)
+            and other.name == self.name
+            and other.param_list == self.param_list
+        )
 
     def __hash__(self):
         return hash(self.name) ^ hash(tuple(self.param_list))
