@@ -63,8 +63,8 @@ constant_numbers = {
     "CC_NON_POTABLE"  : 14,
     "CC_SPECIAL"      : 15,
     "NO_CARGO_CLASS"           : 0,
-    "ALL_NORMAL_CARGO_CLASSES" : 0x1FFF,
-    "ALL_CARGO_CLASSES"        : 0x9FFF,
+    "ALL_NORMAL_CARGO_CLASSES" : 0x7FFF,
+    "ALL_CARGO_CLASSES"        : 0xFFFF,
 
     # engine class
     "ENGINE_CLASS_STEAM"    : 0x00,
@@ -385,14 +385,15 @@ constant_numbers = {
     # station tiles
     "STAT_ALL_TILES"     : 0xFF,
 
-    # station animation triggers
-    "STAT_ANIM_IS_BUILT"              : 0,
-    "STAT_ANIM_CARGO_ARRIVES"         : 1,
-    "STAT_ANIM_CARGO_REMOVED"         : 2,
-    "STAT_ANIM_TRAIN_ENTERS"          : 3,
-    "STAT_ANIM_TRAIN_LEAVES"          : 4,
-    "STAT_ANIM_TRAIN_LOAD_UNLOAD"     : 5,
-    "STAT_ANIM_250_TICKS"             : 6,
+    # bridge pillar flags
+    "BRIDGE_PILLAR_CORNER_W" : 0,
+    "BRIDGE_PILLAR_CORNER_S" : 1,
+    "BRIDGE_PILLAR_CORNER_E" : 2,
+    "BRIDGE_PILLAR_CORNER_N" : 3,
+    "BRIDGE_PILLAR_EDGE_NE"  : 4,
+    "BRIDGE_PILLAR_EDGE_SE"  : 5,
+    "BRIDGE_PILLAR_EDGE_SW"  : 6,
+    "BRIDGE_PILLAR_EDGE_NW"  : 7,
 
     # house flags
     "HOUSE_FLAG_NOT_SLOPED"         : 1,
@@ -517,11 +518,6 @@ constant_numbers = {
     "OBJ_FLAG_RANDOM_ANIMATION": 12,
     "OBJ_FLAG_SCALE_BY_WATER"  : 13,
 
-    # object animation triggers
-    "OBJ_ANIM_IS_BUILT"        : 0,
-    "OBJ_ANIM_PERIODIC"        : 1,
-    "OBJ_ANIM_SYNC"            : 2,
-
     # Special values for object var 0x60
     "OBJECT_TYPE_OTHER_GRF"     : 0xFFFE,
     "OBJECT_TYPE_NO_OBJECT"     : 0xFFFF,
@@ -548,6 +544,14 @@ constant_numbers = {
     "TRAMTYPE_FLAG_HIDDEN"            : 3,
     "TRAMTYPE_FLAG_TOWN_BUILD"        : 4,
 
+    # special values for road/tram/railtype var 0x45
+    "ROADTYPE_OTHER_GRF"        : 0xFE,
+    "ROADTYPE_NO_ROAD"          : 0xFF,
+    "TRAMTYPE_OTHER_GRF"        : 0xFE,
+    "TRAMTYPE_NO_TRAM"          : 0xFF,
+    "RAILTYPE_OTHER_GRF"        : 0xFE,
+    "RAILTYPE_NO_RAIL"          : 0xFF,
+
     # type of default station graphics used for a railtype
     "RAILTYPE_STATION_NORMAL"   : 0,
     "RAILTYPE_STATION_MONORAIL" : 1,
@@ -776,6 +780,13 @@ constant_numbers = {
     "TRIGGER_STATION_TRAIN_LOADS_UNLOADS"   : 4,
     "TRIGGER_STATION_TRAIN_RESERVES"        : 5,
 
+    "TRIGGER_ROAD_STOP_NEW_CARGO"           : 0,
+    "TRIGGER_ROAD_STOP_NO_MORE_CARGO"       : 1,
+    "TRIGGER_ROAD_STOP_VEH_ARRIVES"         : 2,
+    "TRIGGER_ROAD_STOP_VEH_LEAVES"          : 3,
+    "TRIGGER_ROAD_STOP_VEH_LOADS_UNLOADS"   : 4,
+    "TRIGGER_ROAD_STOP_VEH_RESERVES"        : 5,
+
     "TRIGGER_HOUSE_TILELOOP"                : 0,
     "TRIGGER_HOUSE_TOP_TILELOOP"            : 1,
 
@@ -811,6 +822,9 @@ constant_numbers = {
     "ANIM_TRIGGER_INDTILE_RECEIVED_CARGO"     : 3,
     "ANIM_TRIGGER_INDTILE_DISTRIBUTES_CARGO"  : 4,
 
+    "OBJ_ANIM_IS_BUILT"                     : "ANIM_TRIGGER_OBJ_BUILT",
+    "OBJ_ANIM_PERIODIC"                     : "ANIM_TRIGGER_OBJ_TILELOOP",
+    "OBJ_ANIM_SYNC"                         : "ANIM_TRIGGER_OBJ_256_TICKS",
     "ANIM_TRIGGER_OBJ_BUILT"                : 0,
     "ANIM_TRIGGER_OBJ_TILELOOP"             : 1,
     "ANIM_TRIGGER_OBJ_256_TICKS"            : 2,
@@ -829,6 +843,24 @@ constant_numbers = {
     "ANIM_TRIGGER_ROAD_STOP_VEH_LEAVE"      : 4,
     "ANIM_TRIGGER_ROAD_STOP_VEH_LOAD"       : 5,
     "ANIM_TRIGGER_ROAD_STOP_250_TICKS"      : 6,
+    "ANIM_TRIGGER_ROAD_STOP_TILELOOP"       : 7,
+
+    "STAT_ANIM_IS_BUILT"                    : "ANIM_TRIGGER_STAT_BUILT",
+    "STAT_ANIM_CARGO_ARRIVES"               : "ANIM_TRIGGER_STAT_NEW_CARGO",
+    "STAT_ANIM_CARGO_REMOVED"               : "ANIM_TRIGGER_STAT_CARGO_TAKEN",
+    "STAT_ANIM_TRAIN_ENTERS"                : "ANIM_TRIGGER_STAT_VEH_ENTER",
+    "STAT_ANIM_TRAIN_LEAVES"                : "ANIM_TRIGGER_STAT_VEH_LEAVE",
+    "STAT_ANIM_TRAIN_LOAD_UNLOAD"           : "ANIM_TRIGGER_STAT_VEH_LOAD",
+    "STAT_ANIM_250_TICKS"                   : "ANIM_TRIGGER_STAT_250_TICKS",
+    "ANIM_TRIGGER_STAT_BUILT"               : 0,
+    "ANIM_TRIGGER_STAT_NEW_CARGO"           : 1,
+    "ANIM_TRIGGER_STAT_CARGO_TAKEN"         : 2,
+    "ANIM_TRIGGER_STAT_VEH_ENTER"           : 3,
+    "ANIM_TRIGGER_STAT_VEH_LEAVE"           : 4,
+    "ANIM_TRIGGER_STAT_VEH_LOAD"            : 5,
+    "ANIM_TRIGGER_STAT_250_TICKS"           : 6,
+    "ANIM_TRIGGER_STAT_TILELOOP"            : 7,
+    "ANIM_TRIGGER_STAT_TRAIN_RESERVES"      : 8,
 
     # Animation looping
     "ANIMATION_NON_LOOPING"                 : 0,
@@ -1272,7 +1304,7 @@ def add_1920(expr, info):
 
 def map_exponentiate(expr, info):
     """
-    Given a exponent, add an offset to it and compute the exponentiation with base 2.
+    Given an exponent, add an offset to it and compute the exponentiation with base 2.
 
     @param expr: The exponent.
     @type expr: L{Expression}
