@@ -86,7 +86,6 @@ def parse_cli(argv):
         md5_filename=None,
         keep_orphaned=True,
         verbosity=generic.verbosity_level,
-        rebuild_parser=False,
         debug_parser=False,
         allow_extra_zoom=True,
         allow_32bpp=True,
@@ -199,13 +198,6 @@ def parse_cli(argv):
             generic.VERBOSITY_MAX
         ),
     )
-    opt_parser.add_option(
-        "-R",
-        "--rebuild-parser",
-        action="store_true",
-        dest="rebuild_parser",
-        help="Force regeneration of parser tables.",
-    )
     opt_parser.add_option(
         "-D", "--debug-parser", action="store_true", dest="debug_parser", help="Enable debug mode for parser."
     )
@@ -316,7 +308,7 @@ def main(argv):
         input = sys.stdin
     else:
         input = codecs.open(generic.find_file(input_filename), "r", "utf-8")
-        # Only append an output grf name, if no ouput is given, also not implicitly via -M
+        # Only append an output grf name, if no output is given, also not implicitly via -M
         if not opts.outputfile_given and not outputs:
             opts.grf_filename = filename_output_from_input(input_filename, ".grf")
 
@@ -358,7 +350,6 @@ def main(argv):
         opts.crop,
         opts.forced_palette,
         opts.md5_filename,
-        opts.rebuild_parser,
         opts.debug_parser,
         opts.disable_palette_validation,
     )
@@ -384,7 +375,6 @@ def nml(
     crop_sprites,
     forced_palette,
     md5_filename,
-    rebuild_parser,
     debug_parser,
     disable_palette_validation,
 ):
@@ -433,7 +423,7 @@ def nml(
 
     generic.print_progress("Init parser ...")
 
-    nml_parser = parser.NMLParser(rebuild_parser, debug_parser)
+    nml_parser = parser.NMLParser(debug_parser)
     if input_filename is None:
         input_filename = "input"
 
@@ -538,7 +528,7 @@ def nml(
 
         last_file = None
         for f_pair in sprite_files:
-            # Palette is defined by mask_file, if present. Otherwise by the main file.
+            # Palette is defined by mask_file, if present. Otherwise, by the main file.
             f = f_pair[1]
             if f is None:
                 f = f_pair[0]
